@@ -223,6 +223,20 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
                     $_SESSION['delegated_user'] = $delegated_user['username'];
                     $_SESSION['parent_user'] = $delegated_user['parent_username'];
                     $_SESSION['delegated_user_id'] = $delegated_user['id'];
+                    $_SESSION['delegated_display_name'] = $delegated_user['display_name'] ?? '';
+                    
+                    // Store delegated user permissions in session for menu filtering
+                    $_SESSION['delegated_permissions'] = [
+                        'can_manage_domains' => $delegated_user['can_manage_domains'],
+                        'can_manage_sites' => $delegated_user['can_manage_sites'],
+                        'can_manage_databases' => $delegated_user['can_manage_databases'],
+                        'can_manage_email' => $delegated_user['can_manage_email'],
+                        'can_manage_files' => $delegated_user['can_manage_files'],
+                        'can_manage_backups' => $delegated_user['can_manage_backups'],
+                        'can_view_terminal' => $delegated_user['can_view_terminal'],
+                        'can_manage_wordpress' => $delegated_user['can_manage_wordpress']
+                    ];
+                    
                     define('HOME_DIR', $SecMan->get_home_dir($delegated_user['parent_username']));
                 } else {
                     // Delegated session expired or invalid, redirect to login
