@@ -30,6 +30,15 @@ class haproxy_manager {
         $this->haproxy_api_key = $this->settings['haproxy_api_key'] ?? '';
     }
     
+    /**
+     * Destructor to properly close database connection
+     */
+    public function __destruct() {
+        if ($this->db) {
+            $this->db = null; // Close PDO connection
+        }
+    }
+    
     /**
      * Load WHP settings from settings.json
      */
@@ -621,8 +630,7 @@ class haproxy_manager {
             return true;
         } elseif (isset($result['data']['status']) && $result['data']['status'] === 'error' && 
                   strpos($result['data']['message'], 'already blocked') !== false) {
-            // IP is already blocked, consider this a success
-            error_log("HAProxy Manager: IP $ip_address is already blocked");
+            // IP is already blocked, consider this a success but don't log as it's expected
             return true;
         }
         
