@@ -667,6 +667,17 @@ class log_monitor_manager {
             return false;
         }
         
+        // Check if IP is already blocked for this service to prevent infinite loops
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND unblock_time > ?');
+        $stmt->bindValue(1, $service, SQLITE3_TEXT);
+        $stmt->bindValue(2, $ip, SQLITE3_TEXT);
+        $stmt->bindValue(3, time(), SQLITE3_INTEGER);
+        $result = $stmt->execute();
+        if ($result->fetchArray()) {
+            // IP is already blocked for this service, return success without doing anything
+            return true;
+        }
+        
         $block_duration_key = $service . '_block_duration';
         $block_duration = (int)$this->get_config($block_duration_key, 3600);
         
@@ -699,12 +710,42 @@ class log_monitor_manager {
         $stmt->bindValue(7, $firewall_rule_added, SQLITE3_INTEGER);
         $stmt->execute();
         
-        // Also add to main security manager for web interface compatibility
-        $sec_manager->block_ip($ip, $reason, $failed_attempts);
+        // Also add to main security manager for web interface compatibility (skip service blocks to prevent loops)
+        $sec_manager->block_ip($ip, $reason, $failed_attempts, false, true);
         
         return true;
     }
     
+    /**
+     * Unblock an IP address from ALL services
+     * 
+     * @param string $ip IP address to unblock
+     * @return bool True on success, false on failure
+     */
+    public function unblock_ip_from_all_services($ip) {
+        if (!filter_var($ip, FILTER_VALIDATE_IP)) {
+            return false;
+        }
+        
+        // Get all services this IP is blocked from
+        $stmt = $this->db->prepare('SELECT DISTINCT service_type FROM service_blocked_ips WHERE ip_address = ? AND unblock_time > ?');
+        $stmt->bindValue(1, $ip, SQLITE3_TEXT);
+        $stmt->bindValue(2, time(), SQLITE3_INTEGER);
+        $result = $stmt->execute();
+        
+        $services = [];
+        while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
+            $services[] = $row['service_type'];
+        }
+        
+        // Unblock from each service
+        foreach ($services as $service) {
+            $this->unblock_service_ip($service, $ip);
+        }
+        
+        return !empty($services);
+    }
+
     /**
      * Removes an IP address from service-specific block list
      * 
@@ -1142,6 +1183,39 @@ class log_monitor_manager {
         return $blocked;
     }
     
+    /**
+     * Get unique blocked IPs grouped by IP address showing original blocking service
+     * 
+     * @return array Array of unique blocked IPs with original blocking service
+     */
+    public function get_unique_blocked_ips() {
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? ORDER BY ip_address, block_time ASC');
+        $stmt->bindValue(1, time(), SQLITE3_INTEGER);
+        
+        $result = $stmt->execute();
+        $blocked_by_ip = array();
+        
+        while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
+            $ip = $row['ip_address'];
+            
+            if (!isset($blocked_by_ip[$ip])) {
+                // First occurrence of this IP - use it as the blocking method/service
+                $blocked_by_ip[$ip] = $row;
+                $blocked_by_ip[$ip]['blocking_service'] = $row['service_type']; // Store original blocking service
+            } else {
+                // Additional service for this IP - keep original service but update unblock time if later
+                if ($row['unblock_time'] > $blocked_by_ip[$ip]['unblock_time']) {
+                    $blocked_by_ip[$ip]['unblock_time'] = $row['unblock_time'];
+                }
+                
+                // Sum failed attempts from all services
+                $blocked_by_ip[$ip]['failed_attempts'] += $row['failed_attempts'];
+            }
+        }
+        
+        return array_values($blocked_by_ip); // Return indexed array
+    }
+    
     public function get_service_failed_attempts($service, $hours = 24) {
         $stmt = $this->db->prepare('SELECT * FROM service_failed_attempts WHERE service_type = ? AND attempt_time > ? ORDER BY attempt_time DESC');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
