@@ -649,7 +649,8 @@ if (!empty($service_blocked_ips)): ?>
         <div class="card">
             <div class="card-header d-flex justify-content-between align-items-center">
                 <h5 class="card-title mb-0">Blocked IPs</h5>
-                <form method="GET" action="?page=security-management" class="d-flex">
+                <form method="GET" action="" class="d-flex">
+                    <input type="hidden" name="page" value="security-management">
                     <input type="text" class="form-control form-control-sm me-2" name="search" 
                            placeholder="Search IP..." value="<?php echo htmlspecialchars($search); ?>" style="width: 200px;">
                     <button type="submit" class="btn btn-sm btn-primary">Search</button>
